# Exclude private libraries from autogenerated provides and requires
%global __provides_exclude_from ^%{_libdir}/gnome-connections/
%global __requires_exclude ^(%%(find %{buildroot}%{_libdir}/gnome-connections/ -name '*.so' | xargs -n1 basename | sort -u | paste -s -d '|' -))

%global tarball_version %%(echo %{version} | tr '~' '.')
%global url_ver %%(echo %{version} | cut -d. -f1)

Name:       gnome-connections
Version:    43.0
Release:    1%{?dist}
Summary:    A remote desktop client for the GNOME desktop environment

License:    GPLv3+
URL:        https://gitlab.gnome.org/gnome/connections/-/wikis/home
Source0:    https://download.gnome.org/sources/gnome-connections/%{url_ver}/gnome-connections-%{tarball_version}.tar.xz

BuildRequires:  desktop-file-utils
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  libappstream-glib
BuildRequires:  meson
BuildRequires:  vala
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(freerdp2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk-vnc-2.0)
BuildRequires:  pkgconfig(gvncpulse-1.0)
BuildRequires:  pkgconfig(libhandy-1)
BuildRequires:  pkgconfig(libsecret-1)

Requires:       hicolor-icon-theme

# Renamed from connections to gnome-connections in F34
Obsoletes:      connections < 40.0-2
Provides:       connections = %{version}-%{release}

# Remotely EOL and replaced by GNOME Connections.
# https://bugzilla.redhat.com/show_bug.cgi?id=1957981
%if 0%{?fedora} >= 35
Obsoletes:      remotely < 1.0-6
%endif

Provides: bundled(gtk-frdp)

%description
Connections is a remote desktop client for the GNOME desktop environment.

%prep
%autosetup -p1 -n gnome-connections-%{tarball_version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang gnome-connections --with-gnome

# Remove unneeded development files
rm -rf %{buildroot}%{_includedir}/gnome-connections/
rm -rf %{buildroot}%{_libdir}/gnome-connections/girepository-1.0/
rm -rf %{buildroot}%{_libdir}/gnome-connections/pkgconfig/
rm -rf %{buildroot}%{_datadir}/gnome-connections/gir-1.0/
rm -rf %{buildroot}%{_datadir}/gnome-connections/vapi/

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.gnome.Connections.appdata.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Connections.desktop

%files -f gnome-connections.lang
%license COPYING
%doc README.md NEWS
%{_bindir}/gnome-connections
%{_libdir}/gnome-connections/
%{_datadir}/applications/org.gnome.Connections.desktop
%{_datadir}/dbus-1/services/org.gnome.Connections.service
%{_datadir}/glib-2.0/schemas/org.gnome.Connections.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Connections.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Connections-symbolic.svg
%{_datadir}/metainfo/org.gnome.Connections.appdata.xml
%{_datadir}/mime/packages/org.gnome.Connections.xml

%changelog
* Fri Sep 16 2022 Marek Kasik <mkasik@redhat.com> - 43.0-1
- Update to 43.0
- Resolves: #2115889

* Mon Aug 15 2022 Simone Caronni <negativo17@gmail.com> - 43~beta-2
- Rebuild for updated FreeRDP.

* Mon Aug 08 2022 Kalev Lember <klember@redhat.com> - 43~beta-1
- Update to 43.beta

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 42.1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Apr 13 2022 Felipe Borges <feborges@redhat.com> - 42.1.2-1
- Update to 42.1.2

* Thu Apr 07 2022 Felipe Borges <feborges@redhat.com> - 42.1.1-1
- Update to 42.1.1
  rhbz#2069820
  rhbz#2072445
  rhbz#2072462
  rhbz#2072490
  rhbz#2072513

* Tue Apr 05 2022 Felipe Borges <feborges@redhat.com> - 42.1-1
- Update to 42.1
  rhbz#2068015

* Mon Mar 21 2022 David King <amigadave@amigadave.com> - 42.0-1
- Update to 42.0

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 41.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Tue Dec 07 2021 Kalev Lember <klember@redhat.com> - 41.2-1
- Update to 41.2

* Wed Oct 27 2021 Kalev Lember <klember@redhat.com> - 41.1-1
- Update to 41.1

* Fri Sep 17 2021 Kalev Lember <klember@redhat.com> - 41.0-1
- Update to 41.0

* Wed Sep 08 2021 Kalev Lember <klember@redhat.com> - 41~rc-1
- Update to 41.rc

* Mon Aug 23 2021 Kalev Lember <klember@redhat.com> - 41~beta-1
- Update to 41.beta

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 40.0.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Thu May 20 2021 Felipe Borges <feborges@redhat.com> - 40.0.1-4
- Add missing bundled provides

* Mon May 10 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 40.0.1-3
- build: Replace Remotely due EOL with GNOME Connections for f35 | rh#1957981

* Fri Apr 16 2021 Simone Caronni <negativo17@gmail.com> - 40.0.1-2
- Rebuild for updated FreeRDP.

* Thu Apr 15 2021 Felipe Borges <feborges@redhat.com> - 40.0.1-1
- Fix DBus activation

* Mon Mar 22 2021 Kalev Lember <klember@redhat.com> - 40.0-2
- Rename from connections to gnome-connections

* Mon Mar 22 2021 Kalev Lember <klember@redhat.com> - 40.0-1
- Update to 40.0
- Require hicolor-icon-theme for icon directories rather than adwaita
- Use https source URL
- Validate appdata file
- Filter private libraries
- Don't install various development files

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 3.38.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Oct 20 2020 Kalev Lember <klember@redhat.com> - 3.38.1-1
- Update to 3.38.1

* Mon Sep 14 2020 Kalev Lember <klember@redhat.com> - 3.38.0-1
- Update to 3.38.0

* Thu Sep 10 2020 Felipe Borges <feborges@redhat.com> - 3.37.91-1
- Update to 3.37.91

* Mon Aug 10 2020 Felipe Borges <feborges@redhat.com> - 3.37.90-1
- Initial import
